import {
  Icon,
  ListItem,
  ListItemButton,
  ListItemIcon,
  ListItemText,
  SvgIcon,
} from '@suid/material';
import { Component, createSignal, Show } from 'solid-js';
import SystemSecurityUpdateWarningIcon from '@suid/icons-material/SystemSecurityUpdateWarning';
import Dialog from '../dialog';
import dispatch from '../../workers/dispatcher-main';

interface Props {}

const SystemInfo: Component<Props> = (props) => {
  const [open, setOpen] = createSignal(false);
  const [settings, setSettings] = createSignal<any>();
  const [account, setAccount] = createSignal<any>();
  const [error, setError] = createSignal<any>();

  const openDialog = () => {
    setOpen(true);
    dispatch(
      {
        action: 'getSettings',
      },
      (error, result) => {
        console.log({ caller: 'SystemInfo', error, result });
        if (!!error) {
          setError(error);
        }
        if (!!result) {
          setSettings(result);
          dispatch(
            {
              action: 'getAccount',
              params: { id: settings().currentAccountId },
            },
            (error, result) => {
              console.log({ caller: 'SystemInfo', error, result });
              if (!!error) {
                setError(error);
              }
              if (!!result) {
                setAccount(result);
              }
            }
          );
        }
      }
    );
  };

  return (
    <>
      <ListItem>
        <ListItemButton onClick={openDialog}>
          <ListItemIcon>
            <SystemSecurityUpdateWarningIcon />
          </ListItemIcon>
          <ListItemText>System Info</ListItemText>
        </ListItemButton>
      </ListItem>
      <Show when={open()}>
        <Dialog
          open={open()}
          closeHandler={() => setOpen(false)}
          title='System info'
        >
          <div>
            <p>Platform: {window.Capacitor.platform}</p>
            <p>User agent: {navigator.userAgent}</p>
            <p>App release: {import.meta.env.VITE_GIT_COMMIT_HASH}</p>
            <p>Account id: {settings()?.currentAccountId}</p>
            <p>Account name: {account()?.name}</p>
            <p>Remote DB user: {account()?.remoteDbUser}</p>
            <p>Remote DB server: {account()?.remoteDbServer}</p>
          </div>
        </Dialog>
      </Show>
    </>
  );
};

export default SystemInfo;
